/**
 * Random collection of utilities functions/classes.
 */
/**
 * Shuffle an array.
 */
export declare function shuffle(array: any[]): any[];
/**
 * Detects collision between 2 boxes.
 */
export declare function boxBoxCollision(oneX: number, oneY: number, oneWidth: number, oneHeight: number, twoX: number, twoY: number, twoWidth: number, twoHeight: number): boolean;
/**
 * Detects collision between two circles.
 */
export declare function circleCircleCollision(x1: number, y1: number, radius1: number, x2: number, y2: number, radius2: number): boolean;
/**
 * Detects collision between a circle and a point.
 */
export declare function circlePointCollision(circleX: number, circleY: number, circleRadius: number, pointX: number, pointY: number): boolean;
/**
 * Detects collision between a point and a box.
 */
export declare function pointBoxCollision(pointX: number, pointY: number, boxX: number, boxY: number, boxWidth: number, boxHeight: number): boolean;
/**
 * Numeric code of each key.
 */
export declare var KEY_CODE: {
    backspace: number;
    tab: number;
    enter: number;
    esc: number;
    space: number;
    end: number;
    home: number;
    leftArrow: number;
    upArrow: number;
    rightArrow: number;
    downArrow: number;
    del: number;
    "0": number;
    "1": number;
    "2": number;
    "3": number;
    "4": number;
    "5": number;
    "6": number;
    "7": number;
    "8": number;
    "9": number;
    a: number;
    b: number;
    c: number;
    d: number;
    e: number;
    f: number;
    g: number;
    h: number;
    i: number;
    j: number;
    k: number;
    l: number;
    m: number;
    n: number;
    o: number;
    p: number;
    q: number;
    r: number;
    s: number;
    t: number;
    u: number;
    v: number;
    w: number;
    x: number;
    y: number;
    z: number;
    f1: number;
    f2: number;
    f3: number;
    f4: number;
    f5: number;
    f6: number;
    f7: number;
    f8: number;
    f9: number;
    f10: number;
    f11: number;
    f12: number;
};
/**
 * Numeric code of each mouse button.
 */
export declare var MOUSE_CODE: {
    left: number;
    middle: number;
    right: number;
};
/**
 * Returns an object that was obtained by parsing (with json) some data that was saved on `localStorage`.
 *
 * Throws an `Error` exception if:
 * - `key` is not a string.
 * - `key` wasn't found.
 */
export declare function getObject(key: string): any;
/**
 * Saves in the `localStorage` a json string representation of the `value`.
 *
 * Throws an `Error` exception if:
 * - `key` is not a `string`.
 */
export declare function saveObject(key: string, value: any): void;
/**
 * @return If it is an array or not.
 */
export declare function isArray(element: any): boolean;
/**
 * @return If it is a boolean.
 */
export declare function isBoolean(element: any): boolean;
/**
 * @return If it is a function.
 */
export declare function isFunction(element: any): boolean;
/**
 * @return If it is an integer.
 */
export declare function isInteger(value: any): boolean;
/**
 * @return If it is a number.
 */
export declare function isNumber(element: any): boolean;
/**
 * @return If it is a string.
 */
export declare function isString(element: any): boolean;
/**
 * Returns a random float number between `min` and `max` (inclusive).
 *
 * Throws an `Error` exception if:
 * - either `min` or `max` is not a `number`.
 * - the minimum value is bigger than the maximum.
 */
export declare function getRandomFloat(min: number, max: number): number;
/**
 * Returns a random integer number between `min` and `max` (inclusive).
 *
 * Throws an `Error` exception if:
 * - `min` or `max` isn't an integer.
 * - the minimum value is bigger than the maximum.
 */
export declare function getRandomInt(min: number, max: number): number;
/**
 * Returns several different random integers, in the range between `min` and `max` (inclusive).
 *
 * Throws an Error exception if:
 * - `min`, `max` or `howMany` isn't an integer.
 * - the minimum value is bigger than the maximum.
 * - the range is less than the number of integers required.
 */
export declare function getSeveralRandomInts(min: number, max: number, howMany: number): number[];
/**
 * Returns the number of digits in a number.
 * It doesn't consider the minus signal, nor the dot (in floats) as a digit.
 *
 * Throws an `Error` exception if:
 * - the argument is not a number.
 */
export declare function numberOfDigits(theNumber: number): number;
/**
 * Rounds a number to a specified decimal case.
 *
 * Throws an `Error` exception if:
 * - `num` isn't a number.
 * - `dec` isn't an integer.
 * - `dec` is less than 0.
 */
export declare function round(num: number, dec: number): number;
/**
 * Returns a deep clone/copy of the object.
 */
export declare function deepClone(obj: any): any;
/**
 * Enum - A way to associate a string name to a number.
 *
 * @param values The `enum` names. Each name will have an associated number.
 * @param start Starting number for the first name. The number is incremented by one for the next name.
 */
export declare function createEnum(values: string[], start?: number): {
    [key: string]: string | number;
};
/**
 * Converts a time (in milliseconds) to a string (with the number of days/hours...).
 *
 * The number of units to be shown can be set (days/hours, or hours/minutes or minutes/seconds, and not days/hours/minutes for example (for a `totalUnits` of 2)).
 *
 * The units available are: day/hour/minute/second.
 *
 * Throws an `Error` exception if:
 * - the `dateMilliseconds` argument isn't a number.
 */
export declare function timeToString(dateMilliseconds: number, totalUnits?: number): string;
/**
 * Call a function after a certain time has passed. Uses the `window.setTimeout()`.
 */
export declare class Timeout {
    is_active: boolean;
    id: number;
    constructor();
    /**
     * Starts the timeout. If there was an active timeout already, that one is canceled.
     *
     * Throws an `Error` exception if:
     * - `functionToCall` isn't a function.
     * - `interval` isn't a number.
     */
    start(functionToCall: Function, interval: number): void;
    /**
     * Cancels the timeout.
     */
    clear(): void;
}
/**
 * Count-up or count-down timer. Can optionally update an html element.
 */
export declare class Timer {
    is_active: boolean;
    start_value: number;
    count_down: boolean;
    time_count: number;
    end_value?: number;
    end_callback?: () => any;
    tick_callback?: () => any;
    interval_f?: number;
    html_element?: HTMLElement;
    constructor(htmlElement?: HTMLElement);
    /**
     * Start counting.
     * If no endValue is given, it never stops counting.
     *
     * `startValue` and `endValue` are in milliseconds.
     *
     * `endCallback` is called when the timer ends (only if an `endValue` was provided).
     *
     * `tickCallback` is called every second.
     */
    start(args?: {
        startValue?: number;
        endValue?: number;
        endCallback?: () => any;
        tickCallback?: () => any;
        countDown?: boolean;
    }): void;
    /**
     * Resumes the timer with the same settings/values that were set before it was stopped.
     */
    resume(): void;
    /**
     * Stop counting.
     */
    stop(): void;
    /**
     * Stops and resets the count.
     */
    reset(): void;
    /**
     * Restart the timer.
     */
    restart(): void;
    /**
     * Updates the associated html element (if was given) with the current time value.
     */
    updateHtmlElement(): void;
    /**
     * Adds time to the current value in the timer. So for example, if the timer is right now at 4 seconds, and we add 1000 (1 second), it jumps to 5 seconds.
     *
     * @param time In milliseconds.
     */
    add(time: number): void;
    /**
     * Returns a string with the time passed so far.
     */
    getTimeString(): string;
    /**
     * Returns the time it has passed so far, in seconds.
     */
    getTimeSeconds(): number;
    /**
     * Returns the time it has passed so far, in milliseconds.
     */
    getTimeMilliseconds(): number;
}
/**
 * Returns the angle between 2 points in radians.
 * Positive in clockwise direction.
 *
 * Throws an `Error` exception if:
 * - any of the arguments isn't a number.
 */
export declare function calculateAngle(aX: number, aY: number, bX: number, bY: number): number;
/**
 * Distance between 2 points.
 *
 * Throws an `Error` exception if:
 * - any of the arguments isn't a number.
 */
export declare function calculateDistance(aX: number, aY: number, bX: number, bY: number): number;
/**
 * Converts a number in `radians` to `degrees` and returns it.
 *
 * Throws an `Error` exception if:
 * - the argument isn't a number.
 */
export declare function toDegrees(radians: number): number;
/**
 * Converts a number in `degrees` to `radians` and returns it.
 *
 * Throws an `Error` exception if:
 * - the argument isn't a number.
 */
export declare function toRadians(degrees: number): number;
